package repository

import (
	"database/sql"
	"errors"
	"git.sch9.ru/new_gate/ms-tester/pkg"
	"github.com/jackc/pgerrcode"
	"github.com/jackc/pgx/v5/pgconn"
)

func handlePgErr(err error, op string) error {
	var pgErr *pgconn.PgError
	if errors.As(err, &pgErr) {
		if pgerrcode.IsIntegrityConstraintViolation(pgErr.Code) {
			return pkg.Wrap(pkg.ErrBadInput, err, op, pgErr.Message)
		}
		if pgerrcode.IsNoData(pgErr.Code) {
			return pkg.Wrap(pkg.ErrNotFound, err, op, pgErr.Message)
		}
	}

	if errors.Is(err, sql.ErrNoRows) {
		return pkg.Wrap(pkg.ErrNotFound, err, op, "no rows found")
	}

	return pkg.Wrap(pkg.ErrUnhandled, err, op, "unexpected error")
}
